NoteBooks
#############

ipython notebook can be downloaded from this section. You can either see the
results via nbviewer, or download and run them yourself. To do so, download the
notebook and open a shell where is saved the file. Type::

    ipython notebook

You should see the notebook name. Click on it and you are ready to try. Cels can
be executed by typing CTRL+enter

UniProt
----------

Here is a ipython notebook dedicated to UniProt, which can be 
downloaded :download:`notebooks/UniProt.ipynb` or view its results on 
`uniprot nbviewer <https://nbviewer.ipython.org/url/github.com/cokelaer/bioservices/blob/master/doc/notebooks/UniProt.ipynb>`_

BioModels
----------

Here is a ipython notebook dedicated to BioModels, which can be 
downloaded :download:`notebooks/BioModels.ipynb` or view its results on 
`biomodels nbviewer <https://nbviewer.ipython.org/url/github.com/cokelaer/bioservices/blob/master/doc/notebooks/BioModels.ipynb>`_


ChEMBL
----------

Here is a ipython notebook dedicated to ChEMBL, which can be 
downloaded :download:`notebooks/ChEMBL.ipynb` or view its results on 
`chembl nbviewer <https://nbviewer.ipython.org/github/cokelaer/bioservices/blob/master/doc/notebooks/ChEMBL.ipynb>`_

Entrez/Eutils
---------------

Here is a ipython notebook dedicated to EUtils, which can be 
downloaded :download:`notebooks/Entrez_EUtils.ipynb` or view its results on 
`eutil nbviewer <https://nbviewer.ipython.org/url/github.com/cokelaer/bioservices/blob/master/doc/notebooks/Entrez_EUtils.ipynb>`_

KEGG
---------

Here is a ipython notebook dedicated to KEGG, which can be 
downloaded :download:`notebooks/KEGG.ipynb` or view its results on
`kegg nbviewer <https://nbviewer.ipython.org/url/github.com/cokelaer/bioservices/blob/master/doc/notebooks/KEGG.ipynb>`_

MUSCLE
---------

Here is a ipython notebook dedicated to MUSCLE, which can be 
downloaded :download:`notebooks/MUSCLE.ipynb` or view its results on 
`muscle nbviewer <https://nbviewer.ipython.org/url/github.com/cokelaer/bioservices/blob/master/doc/notebooks/MUSCLE.ipynb>`_


NCBIBlast
---------

Here is a ipython notebook dedicated to NCBIblast, which can be 
downloaded :download:`notebooks/NCBIBlast.ipynb` or view its results on 
`ncbiblast nbviewer <https://nbviewer.ipython.org/url/github.com/cokelaer/bioservices/blob/master/doc/notebooks/NCBIBlast.ipynb>`_

WikiPathway
-------------

Here is a ipython notebook dedicated to WikiPathway, which can be 
downloaded :download:`notebooks/WikiPathway.ipynb` or view its results on 
`wikipathway nbviewer <https://nbviewer.ipython.org/url/github.com/cokelaer/bioservices/blob/master/doc/notebooks/WikiPathway.ipynb>`_

Gene Mapping
================
Here is a ipython notebook dedicated to Gene Mapping, which can be 
downloaded :download:`notebooks/Gene_Mapping.ipynb` or view its results on 
`gene mapping nbviewer <http://nbviewer.ipython.org/url/github.com/cokelaer/bioservices/blob/master/doc/notebooks/Gene_Mapping.ipynb>`_


BioMart
=======
Here is a ipython notebook dedicated to BioMart, which can be 
downloaded :download:`notebooks/BioMart` or view its results on 
`chembl biomiart <https://nbviewer.ipython.org/url/github.com/cokelaer/bioservices/blob/master/doc/notebooks/BioMart.ipynb>`_

Ensembl
=======

Here is a ipython notebook dedicated to Ensembl, which can be 
downloaded :download:`notebooks/Ensembl.ipynb` or view its results on 
`ensembl nbviewer <https://nbviewer.ipython.org/url/github.com/cokelaer/bioservices/blob/master/doc/notebooks/Ensembl.ipynb>`_

